#
# spec file for package microdnf
#
# Copyright (c) 2022 SUSE LLC
# Copyright (c) 2020-2021 Neal Gompa <ngompa13@gmail.com>.
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%global libdnf_version 0.62.0

Name:           microdnf
Version:        3.9.1
Release:        1.9
Summary:        Lightweight implementation of DNF in C
Group:          System/Packages
License:        GPL-2.0-or-later
URL:            https://github.com/rpm-software-management/microdnf
Source0:        %{url}/archive/%{version}/%{name}-%{version}.tar.gz

BuildRequires:  gcc
BuildRequires:  help2man
BuildRequires:  meson >= 0.36.0
BuildRequires:  pkgconfig(glib-2.0) >= 2.44.0
BuildRequires:  pkgconfig(gobject-2.0) >= 2.44.0
BuildRequires:  pkgconfig(libdnf) >= %{libdnf_version}
BuildRequires:  pkgconfig(libpeas-1.0) >= 1.20.0
BuildRequires:  pkgconfig(smartcols)

# Attempt to install the DNF package manager configuration skeleton
Recommends:     dnf-data

# Stricter dependency to keep things sane
%requires_ge %(rpm -qf "$(readlink -f %{_libdir}/libdnf.so)")

%description
Micro DNF is a lightweight C implementation of DNF, designed to be used
for doing simple packaging actions when you don't need full-blown DNF and
you want the tiniest useful environments possible.

That is, you don't want any interpreter stack and you want the most
minimal environment possible so you can build up to exactly what you need.

%prep
%autosetup -p1

%build
%meson
%meson_build

%install
%meson_install

%check
%meson_test

%files
%license COPYING
%doc README.md
%{_mandir}/man8/microdnf.8*
%{_bindir}/%{name}

%changelog
* Sat Oct 15 2022 Andreas Stieger <andreas.stieger@gmx.de>
- update to 3.9.1:
  * Add the leaves command: Lists installed packages that are not
    required by other installed packages. Treat recommends as
    dependencies when install_weak_deps=True
  * UI tweaks
* Tue Apr 13 2021 Neal Gompa <ngompa13@gmail.com>
- Update to 3.8.0
  + Add "makecache" command
  + Add "distro-sync" command
* Fri Feb 12 2021 Neal Gompa <ngompa13@gmail.com>
- Update to 3.7.1
  + Bump minimum version of libdnf to 0.56.0
  + Fix download subcommand to build with glib2 2.44.0
* Wed Feb  3 2021 Neal Gompa <ngompa13@gmail.com>
- Update to 3.7.0
  + Add support for command aliases
  + Rename "update" to "upgrade" command
  + Add "update" alias to "upgrade" command
  + Add "download" command
  + Add support for user confirmation
  + Default to user confirmation like DNF
* Sun Dec  6 2020 Neal Gompa <ngompa13@gmail.com>
- Update to 3.6.0
  + Add support for setting allow_vendor_change
  + Add support for setting a platform module ID
- Drop patches incorporated into this release
  + Patch: 0001-Add-support-for-setting-allow_vendor_change.patch
  + Patch: 0001-Add-support-for-setting-a-platform-module-ID.patch
- Add weak dependency for DNF configuration skeleton
* Sun Nov 29 2020 Neal Gompa <ngompa13@gmail.com>
- Update to 3.5.1
  + Add module enable and disable commands
  + Add reports of module changes
  + Add "module enable" command
  + Add subcommands support
  + Print info about obsoleted packages before transaction (rh#1855542)
  + Relicense to GPLv2+
- Backport fixes from upstream
  + Patch: 0001-Add-support-for-setting-allow_vendor_change.patch
  + Patch: 0001-Add-support-for-setting-a-platform-module-ID.patch
* Sun Jan 19 2020 Neal Gompa <ngompa13@gmail.com>
- Initial package based on Fedora and Mageia packaging
